# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.mongodb.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/mdb/mongodb/v1/backup_service.proto\x12\x1byandex.cloud.mdb.mongodb.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/mdb/mongodb/v1/backup.proto\"+\n\x10GetBackupRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"s\n\x12ListBackupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"d\n\x13ListBackupsResponse\x12\x34\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.mongodb.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\".\n\x13\x44\x65leteBackupRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\")\n\x14\x44\x65leteBackupMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t2\xef\x03\n\rBackupService\x12\x8a\x01\n\x03Get\x12-.yandex.cloud.mdb.mongodb.v1.GetBackupRequest\x1a#.yandex.cloud.mdb.mongodb.v1.Backup\"/\x82\xd3\xe4\x93\x02)\x12\'/managed-mongodb/v1/backups/{backup_id}\x12\x8e\x01\n\x04List\x12/.yandex.cloud.mdb.mongodb.v1.ListBackupsRequest\x1a\x30.yandex.cloud.mdb.mongodb.v1.ListBackupsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/managed-mongodb/v1/backups\x12\xbf\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.mdb.mongodb.v1.DeleteBackupRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*-\n\x14\x44\x65leteBackupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/managed-mongodb/v1/backups/{backup_id}Bj\n\x1fyandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodb'
  _GETBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _GETBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _LISTBACKUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _DELETEBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _DELETEBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _BACKUPSERVICE.methods_by_name['Get']._options = None
  _BACKUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/managed-mongodb/v1/backups/{backup_id}'
  _BACKUPSERVICE.methods_by_name['List']._options = None
  _BACKUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\035\022\033/managed-mongodb/v1/backups'
  _BACKUPSERVICE.methods_by_name['Delete']._options = None
  _BACKUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBackupMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/managed-mongodb/v1/backups/{backup_id}'
  _globals['_GETBACKUPREQUEST']._serialized_start=258
  _globals['_GETBACKUPREQUEST']._serialized_end=301
  _globals['_LISTBACKUPSREQUEST']._serialized_start=303
  _globals['_LISTBACKUPSREQUEST']._serialized_end=418
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=420
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=520
  _globals['_DELETEBACKUPREQUEST']._serialized_start=522
  _globals['_DELETEBACKUPREQUEST']._serialized_end=568
  _globals['_DELETEBACKUPMETADATA']._serialized_start=570
  _globals['_DELETEBACKUPMETADATA']._serialized_end=611
  _globals['_BACKUPSERVICE']._serialized_start=614
  _globals['_BACKUPSERVICE']._serialized_end=1109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/logging/v1/log_resource.proto\x12\x17yandex.cloud.logging.v1\x1a\x1dyandex/cloud/validation.proto\"y\n\x10LogEntryResource\x12\x31\n\x04type\x18\x01 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?\x12\x32\n\x02id\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-zA-Z0-9][-a-zA-Z0-9_.]{0,63})?\"-\n\x10LogGroupResource\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\tBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _LOGENTRYRESOURCE.fields_by_name['type']._options = None
  _LOGENTRYRESOURCE.fields_by_name['type']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _LOGENTRYRESOURCE.fields_by_name['id']._options = None
  _LOGENTRYRESOURCE.fields_by_name['id']._serialized_options = b'\362\3071\"([a-zA-Z0-9][-a-zA-Z0-9_.]{0,63})?'
  _globals['_LOGENTRYRESOURCE']._serialized_start=102
  _globals['_LOGENTRYRESOURCE']._serialized_end=223
  _globals['_LOGGROUPRESOURCE']._serialized_start=225
  _globals['_LOGGROUPRESOURCE']._serialized_end=270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/pxf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xc5\x04\n\tPXFConfig\x12\x42\n\x12\x63onnection_timeout\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12>\n\x0eupload_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12<\n\x0bmax_threads\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x42\n\x1epool_allow_core_thread_timeout\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0epool_core_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x41\n\x13pool_queue_capacity\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\rpool_max_size\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x36\n\x03xmx\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x34-16384\x12\x36\n\x03xms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x34-16384\"\xd9\x01\n\x0cPXFConfigSet\x12H\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigB\x04\xe8\xc7\x31\x01\x12=\n\x0buser_config\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\x12@\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigBp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.pxf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _PXFCONFIG.fields_by_name['connection_timeout']._options = None
  _PXFCONFIG.fields_by_name['connection_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFCONFIG.fields_by_name['upload_timeout']._options = None
  _PXFCONFIG.fields_by_name['upload_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFCONFIG.fields_by_name['max_threads']._options = None
  _PXFCONFIG.fields_by_name['max_threads']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['pool_core_size']._options = None
  _PXFCONFIG.fields_by_name['pool_core_size']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['pool_queue_capacity']._options = None
  _PXFCONFIG.fields_by_name['pool_queue_capacity']._serialized_options = b'\372\3071\003>=0'
  _PXFCONFIG.fields_by_name['pool_max_size']._options = None
  _PXFCONFIG.fields_by_name['pool_max_size']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['xmx']._options = None
  _PXFCONFIG.fields_by_name['xmx']._serialized_options = b'\372\3071\01064-16384'
  _PXFCONFIG.fields_by_name['xms']._options = None
  _PXFCONFIG.fields_by_name['xms']._serialized_options = b'\372\3071\01064-16384'
  _PXFCONFIGSET.fields_by_name['effective_config']._options = None
  _PXFCONFIGSET.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_PXFCONFIG']._serialized_start=138
  _globals['_PXFCONFIG']._serialized_end=719
  _globals['_PXFCONFIGSET']._serialized_start=722
  _globals['_PXFCONFIGSET']._serialized_end=939
# @@protoc_insertion_point(module_scope)
